# laygo2

### Notice: From Sep. 2024, the open-source version of laygo2 has been in "Maintenance Mode". Updates are restricted to bug fixes and marginal improvements. 
Please contact us to access advanced features in the private version.

[![PyPI version](https://badge.fury.io/py/laygo2.svg?)](https://pypi.org/project/laygo2/)

(The commit history is cleaned up on 6-27-2022)

The LAYout with Gridded Object 2 (laygo2) is an automated layout generation framework
for custom integrated circuits. 
[\[Source code\]](https://github.com/niftylab/laygo2) 
[\[Documentation\]](https://laygo2.github.io/) 
[\[Colab tutorial\]](https://colab.research.google.com/drive/1tpuUvqb6BujzZI6RBf2cFdAfMqBsxpep?usp=sharing) 

LAYGO2 provides a rich and productive layout design environment for designers
with several advanced concepts such templates and grids.

For further documentation, see [https://laygo2.github.io/](https://laygo2.github.io/).

List of developers and contributors:
- Jaeduk Han
- Taeho Shin
- Dongjun Lee
- Dongwhee Kim
- Gaeryun Sung
- Wookjin Shin
- Yunseong Jo
- Hyungjoo Park
- Seonghyun Park
- Youngmin Oh
- Taeseung Kang
- Curtis Mayberry

